@@ -1,13 +1,14 @@
 #ifndef STAN_LANG_AST_FUN_IS_SPACE_DEF_HPP
 #define STAN_LANG_AST_FUN_IS_SPACE_DEF_HPP
 
+#include <stan/io/is_whitespace.hpp>
 #include <stan/lang/ast/fun/is_space.hpp>
 
 namespace stan {
   namespace lang {
 
     bool is_space(char c) {
-      return c == ' ' || c == '\n' || c == '\r' || c == '\t';
+      return stan::io::is_whitespace(c);
     }
 
   }
