@@ -15,20 +15,18 @@ namespace stan {
 
     bool is_user_defined(const std::string& name,
                          const std::vector<expression>& args) {
-      std::vector<expr_type> arg_types;
-      for (size_t i = 0; i <  args.size(); ++i)
-        arg_types.push_back(args[i].expression_type());
+      std::vector<bare_expr_type> arg_types;
+      for (size_t i = 0; i < args.size(); ++i)
+        arg_types.push_back(args[i].bare_type());
       function_signature_t sig;
-      int matches
-        = function_signatures::instance()
-        .get_signature_matches(name, arg_types, sig);
+      int matches = function_signatures::instance().get_signature_matches(
+                                                    name, arg_types, sig);
       if (matches != 1)
-        return false;  // reall shouldn't come up;  throw instead?
-      std::pair<std::string, function_signature_t>
-        name_sig(name, sig);
+        return false;
+      std::pair<std::string, function_signature_t> name_sig(name, sig);
       return function_signatures::instance().is_user_defined(name_sig);
     }
 
-  }
-}
+  }  // namespace lang
+}  // namespace stan
 #endif
