@@ -18,6 +18,12 @@ namespace stan {
       return !op_.compare("=");
     }
 
+    bool assgn::lhs_var_has_sliced_idx() const {
+      for (const auto& idx : idxs_)
+        if (is_multi_index(idx)) return true;
+      return false;
+    }
+
     bool assgn::lhs_var_occurs_on_rhs() const {
       var_occurs_vis vis(lhs_var_);
       return boost::apply_visitor(vis, rhs_.expr_);
