@@ -3,8 +3,6 @@
 
 #include <stan/lang/ast.hpp>
 #include <stan/lang/generator/constants.hpp>
-#include <stan/lang/generator/write_param_names_visgen.hpp>
-#include <boost/variant/apply_visitor.hpp>
 #include <ostream>
 
 namespace stan {
@@ -19,17 +17,19 @@ namespace stan {
      * @param[in,out] o stream for generating
      */
     void generate_param_names_method(const program& prog, std::ostream& o) {
-      write_param_names_visgen vis(o);
       o << EOL << INDENT
         << "void get_param_names(std::vector<std::string>& names__) const {"
         << EOL;
       o << INDENT2 << "names__.resize(0);" << EOL;
       for (size_t i = 0; i < prog.parameter_decl_.size(); ++i)
-        boost::apply_visitor(vis, prog.parameter_decl_[i].decl_);
+        o << INDENT2 << "names__.push_back(\""
+           << prog.parameter_decl_[i].name() << "\");" << EOL;
       for (size_t i = 0; i < prog.derived_decl_.first.size(); ++i)
-        boost::apply_visitor(vis, prog.derived_decl_.first[i].decl_);
+        o << INDENT2 << "names__.push_back(\""
+           << prog.derived_decl_.first[i].name() << "\");" << EOL;
       for (size_t i = 0; i < prog.generated_decl_.first.size(); ++i)
-        boost::apply_visitor(vis, prog.generated_decl_.first[i].decl_);
+        o << INDENT2 << "names__.push_back(\""
+          << prog.generated_decl_.first[i].name() << "\");" << EOL;
       o << INDENT << "}" << EOL2;
     }
 
