@@ -3,6 +3,7 @@
 
 #include <stan/io/stan_csv_reader.hpp>
 #include <stan/math/prim/mat.hpp>
+#include <stan/analyze/mcmc/compute_effective_sample_size.hpp>
 #include <boost/accumulators/accumulators.hpp>
 #include <boost/accumulators/statistics/stats.hpp>
 #include <boost/accumulators/statistics/mean.hpp>
@@ -209,89 +210,6 @@ namespace stan {
         return ac2;
       }
 
-      /**
-       * Returns the effective sample size for the specified parameter
-       * across all kept samples.
-       *
-       * The implementation is close to the effective sample size
-       * description in BDA3 (p. 286-287).  See more details in Stan
-       * reference manual section "Effective Sample Size".
-       *
-       * Current implementation takes the minimum number of samples
-       * across chains as the number of samples per chain.
-       *
-       * @param VectorXd
-       * @param Dynamic
-       * @param samples
-       *
-       * @return
-       */
-      double effective_sample_size(const Eigen::Matrix<Eigen::VectorXd,
-                                   Dynamic, 1> &samples) const {
-        int chains = samples.size();
-
-        // need to generalize to each jagged samples per chain
-        int n_samples = samples(0).size();
-        for (int chain = 1; chain < chains; chain++) {
-          n_samples = std::min(n_samples,
-                               static_cast<int>(samples(chain).size()));
-        }
-
-        Eigen::Matrix<Eigen::VectorXd, Dynamic, 1> acov(chains);
-        for (int chain = 0; chain < chains; chain++) {
-          acov(chain) = autocovariance(samples(chain));
-        }
-
-        Eigen::VectorXd chain_mean(chains);
-        Eigen::VectorXd chain_var(chains);
-        for (int chain = 0; chain < chains; chain++) {
-          double n_kept_samples = num_kept_samples(chain);
-          chain_mean(chain) = mean(samples(chain));
-          chain_var(chain) = acov(chain)(0)*n_kept_samples/(n_kept_samples-1);
-        }
-
-        double mean_var = mean(chain_var);
-        double var_plus = mean_var*(n_samples-1)/n_samples;
-        if (chains > 1)
-          var_plus += variance(chain_mean);
-        Eigen::VectorXd rho_hat_t(n_samples);
-        rho_hat_t.setZero();
-        Eigen::VectorXd acov_t(chains);
-        for (int chain = 0; chain < chains; chain++)
-          acov_t(chain) = acov(chain)(1);
-        double rho_hat_even = 1;
-        double rho_hat_odd = 1 - (mean_var - mean(acov_t)) / var_plus;
-        rho_hat_t(1) = rho_hat_odd;
-        // Geyer's initial positive sequence
-        int max_t = 1;
-        for (int t = 1;
-             (t < (n_samples - 2) && (rho_hat_even + rho_hat_odd) >= 0);
-             t += 2) {
-          for (int chain = 0; chain < chains; chain++)
-            acov_t(chain) = acov(chain)(t + 1);
-          rho_hat_even = 1 - (mean_var - mean(acov_t)) / var_plus;
-          for (int chain = 0; chain < chains; chain++)
-            acov_t(chain) = acov(chain)(t + 2);
-          rho_hat_odd = 1 - (mean_var - mean(acov_t)) / var_plus;
-          if ((rho_hat_even + rho_hat_odd) >= 0) {
-            rho_hat_t(t + 1) = rho_hat_even;
-            rho_hat_t(t + 2) = rho_hat_odd;
-          }
-          max_t = t + 2;
-        }
-        // Geyer's initial monotone sequence
-        for (int t = 3; t <= max_t - 2; t += 2) {
-          if (rho_hat_t(t + 1) + rho_hat_t(t + 2) >
-              rho_hat_t(t - 1) + rho_hat_t(t)) {
-            rho_hat_t(t + 1) = (rho_hat_t(t - 1) + rho_hat_t(t)) / 2;
-            rho_hat_t(t + 2) = rho_hat_t(t + 1);
-          }
-        }
-        double ess = chains * n_samples;
-        ess /= (1 + 2 * rho_hat_t.sum());
-        return ess;
-      }
-
       /**
        * Return the split potential scale reduction (split R hat)
        * for the specified parameter.
@@ -689,12 +607,17 @@ namespace stan {
 
       // FIXME: reimplement using autocorrelation.
       double effective_sample_size(const int index) const {
-        Eigen::Matrix<Eigen::VectorXd, Dynamic, 1>
-          samples(num_chains());
-        for (int chain = 0; chain < num_chains(); chain++) {
-          samples(chain) = this->samples(chain, index);
+        int n_chains = num_chains();
+        std::vector<const double*> draws(n_chains);
+        std::vector<size_t> sizes(n_chains);
+        int n_kept_samples = 0;
+        for (int chain = 0; chain < n_chains; ++chain) {
+          n_kept_samples = num_kept_samples(chain);
+          draws[chain]
+            = samples_(chain).col(index).bottomRows(n_kept_samples).data();
+          sizes[chain] = n_kept_samples;
         }
-        return effective_sample_size(samples);
+        return analyze::compute_effective_sample_size(draws, sizes);
       }
 
       double effective_sample_size(const std::string& name) const {
