@@ -77,7 +77,7 @@ namespace stan {
         static const char* function =
           "stan::variational::normal_meanfield";
         stan::math::check_size_match(function,
-                             "Dimension of mean vector", dimension_,
+                             "Dimension of mean vector", mu_.size(),
                              "Dimension of log std vector", omega_.size() );
         stan::math::check_not_nan(function, "Mean vector", mu_);
         stan::math::check_not_nan(function, "Log std vector", omega_);
@@ -112,7 +112,7 @@ namespace stan {
 
         stan::math::check_size_match(function,
                                "Dimension of input vector", mu.size(),
-                               "Dimension of current vector", dimension_);
+                               "Dimension of current vector", dimension());
         stan::math::check_not_nan(function, "Input vector", mu);
         mu_ = mu;
       }
@@ -132,7 +132,7 @@ namespace stan {
 
         stan::math::check_size_match(function,
                                "Dimension of input vector", omega.size(),
-                               "Dimension of current vector", dimension_);
+                               "Dimension of current vector", dimension());
         stan::math::check_not_nan(function, "Input vector", omega);
         omega_ = omega;
       }
@@ -142,8 +142,8 @@ namespace stan {
        * approximation to zero.
        */
       void set_to_zero() {
-        mu_ = Eigen::VectorXd::Zero(dimension_);
-        omega_ = Eigen::VectorXd::Zero(dimension_);
+        mu_ = Eigen::VectorXd::Zero(dimension());
+        omega_ = Eigen::VectorXd::Zero(dimension());
       }
 
       /**
@@ -187,7 +187,7 @@ namespace stan {
         static const char* function =
           "stan::variational::normal_meanfield::operator=";
         stan::math::check_size_match(function,
-                             "Dimension of lhs", dimension_,
+                             "Dimension of lhs", dimension(),
                              "Dimension of rhs", rhs.dimension());
         mu_ = rhs.mu();
         omega_ = rhs.omega();
@@ -209,7 +209,7 @@ namespace stan {
         static const char* function =
           "stan::variational::normal_meanfield::operator+=";
         stan::math::check_size_match(function,
-                             "Dimension of lhs", dimension_,
+                             "Dimension of lhs", dimension(),
                              "Dimension of rhs", rhs.dimension());
         mu_ += rhs.mu();
         omega_ += rhs.omega();
@@ -233,7 +233,7 @@ namespace stan {
         static const char* function =
           "stan::variational::normal_meanfield::operator/=";
         stan::math::check_size_match(function,
-                             "Dimension of lhs", dimension_,
+                             "Dimension of lhs", dimension(),
                              "Dimension of rhs", rhs.dimension());
         mu_.array() /= rhs.mu().array();
         omega_.array() /= rhs.omega().array();
@@ -297,7 +297,7 @@ namespace stan {
        * @return Entropy of this approximation.
        */
       double entropy() const {
-        return 0.5 * static_cast<double>(dimension_) *
+        return 0.5 * static_cast<double>(dimension()) *
                (1.0 + stan::math::LOG_TWO_PI) + omega_.sum();
       }
 
@@ -317,31 +317,13 @@ namespace stan {
         static const char* function =
           "stan::variational::normal_meanfield::transform";
         stan::math::check_size_match(function,
-                         "Dimension of mean vector", dimension_,
+                         "Dimension of mean vector", dimension(),
                          "Dimension of input vector", eta.size() );
         stan::math::check_not_nan(function, "Input vector", eta);
         // exp(omega) * eta + mu
         return eta.array().cwiseProduct(omega_.array().exp()) + mu_.array();
       }
 
-      /**
-       * Assign a draw from this mean field approximation to the
-       * specified vector using the specified random number generator.
-       *
-       * @tparam BaseRNG Class of random number generator.
-       * @param[in] rng Base random number generator.
-       * @param[in,out] eta Vector to which the draw is assigned; must
-       * already be properly sized.
-       * @throws std::range_error If the index is out of range.
-       */
-      template <class BaseRNG>
-      void sample(BaseRNG& rng, Eigen::VectorXd& eta) const {
-        // Draw from standard normal and transform to real-coordinate space
-        for (int d = 0; d < dimension_; ++d)
-          eta(d) = stan::math::normal_rng(0, 1, rng);
-        eta = transform(eta);
-      }
-
       /**
        * Calculates the "blackbox" gradient with respect to both the
        * location vector (mu) and the log-std vector (omega) in
@@ -373,23 +355,23 @@ namespace stan {
 
         stan::math::check_size_match(function,
                         "Dimension of elbo_grad", elbo_grad.dimension(),
-                        "Dimension of variational q", dimension_);
+                        "Dimension of variational q", dimension());
         stan::math::check_size_match(function,
-                        "Dimension of variational q", dimension_,
+                        "Dimension of variational q", dimension(),
                         "Dimension of variables in model", cont_params.size());
 
-        Eigen::VectorXd mu_grad    = Eigen::VectorXd::Zero(dimension_);
-        Eigen::VectorXd omega_grad = Eigen::VectorXd::Zero(dimension_);
+        Eigen::VectorXd mu_grad    = Eigen::VectorXd::Zero(dimension());
+        Eigen::VectorXd omega_grad = Eigen::VectorXd::Zero(dimension());
         double tmp_lp = 0.0;
-        Eigen::VectorXd tmp_mu_grad = Eigen::VectorXd::Zero(dimension_);
-        Eigen::VectorXd eta  = Eigen::VectorXd::Zero(dimension_);
-        Eigen::VectorXd zeta = Eigen::VectorXd::Zero(dimension_);
+        Eigen::VectorXd tmp_mu_grad = Eigen::VectorXd::Zero(dimension());
+        Eigen::VectorXd eta  = Eigen::VectorXd::Zero(dimension());
+        Eigen::VectorXd zeta = Eigen::VectorXd::Zero(dimension());
 
         // Naive Monte Carlo integration
         static const int n_retries = 10;
         for (int i = 0, n_monte_carlo_drop = 0; i < n_monte_carlo_grad; ) {
           // Draw from standard normal and transform to real-coordinate space
-          for (int d = 0; d < dimension_; ++d)
+          for (int d = 0; d < dimension(); ++d)
             eta(d) = stan::math::normal_rng(0, 1, rng);
           zeta = transform(eta);
           try {
