@@ -8,17 +8,15 @@
 #include <stan/math/prim/scal/fun/constants.hpp>
 
 namespace stan {
-  namespace math {
+namespace math {
 
-    template <typename T>
-    inline
-    fvar<T>
-    logit(const fvar<T>& x) {
-      if (x.val_ > 1 || x.val_ < 0)
-        return fvar<T>(NOT_A_NUMBER, NOT_A_NUMBER);
-      else
-        return fvar<T>(logit(x.val_), x.d_ / (x.val_ - square(x.val_)));
-    }
-  }
+template <typename T>
+inline fvar<T> logit(const fvar<T>& x) {
+  if (x.val_ > 1 || x.val_ < 0)
+    return fvar<T>(NOT_A_NUMBER, NOT_A_NUMBER);
+  else
+    return fvar<T>(logit(x.val_), x.d_ / (x.val_ - square(x.val_)));
 }
+}  // namespace math
+}  // namespace stan
 #endif
