@@ -14,17 +14,9 @@ Eigen::Matrix<typename boost::math::tools::promote_args<T1, T2>::type, R1, C1>
 diag_post_multiply(const Eigen::Matrix<T1, R1, C1>& m1,
                    const Eigen::Matrix<T2, R2, C2>& m2) {
   check_vector("diag_post_multiply", "m2", m2);
-  int m1_cols = m1.cols();
   check_size_match("diag_post_multiply", "m2.size()", m2.size(), "m1.cols()",
-                   m1_cols);
-  int m1_rows = m1.rows();
-  Eigen::Matrix<typename boost::math::tools::promote_args<T1, T2>::type, R1, C1>
-      result(m1_rows, m1_cols);
-
-  for (int j = 0; j < m1_cols; ++j)
-    for (int i = 0; i < m1_rows; ++i)
-      result(i, j) = m2(j) * m1(i, j);
-  return result;
+                   m1.cols());
+  return m1 * m2.asDiagonal();
 }
 
 }  // namespace math
