@@ -2,7 +2,7 @@
 #define STAN_MATH_PRIM_MAT_FUN_ERF_HPP
 
 #include <stan/math/prim/mat/vectorize/apply_scalar_unary.hpp>
-#include <boost/math/special_functions/erf.hpp>
+#include <stan/math/prim/scal/fun/erf.hpp>
 
 namespace stan {
 namespace math {
@@ -17,7 +17,6 @@ namespace math {
 struct erf_fun {
   template <typename T>
   static inline T fun(const T& x) {
-    using boost::math::erf;
     return erf(x);
   }
 };
