@@ -1,8 +1,6 @@
 #ifndef STAN_MATH_REV_MAT_FUN_QUAD_FORM_HPP
 #define STAN_MATH_REV_MAT_FUN_QUAD_FORM_HPP
 
-#include <boost/utility/enable_if.hpp>
-#include <boost/type_traits.hpp>
 #include <stan/math/rev/core.hpp>
 #include <stan/math/prim/mat/fun/Eigen.hpp>
 #include <stan/math/prim/mat/fun/typedefs.hpp>
@@ -12,11 +10,12 @@
 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
 #include <stan/math/prim/mat/err/check_square.hpp>
 #include <stan/math/prim/mat/err/check_symmetric.hpp>
+#include <type_traits>
 
 namespace stan {
 namespace math {
 
-namespace {
+namespace internal {
 template <typename Ta, int Ra, int Ca, typename Tb, int Rb, int Cb>
 class quad_form_vari_alloc : public chainable_alloc {
  private:
@@ -109,33 +108,33 @@ class quad_form_vari : public vari {
 
   quad_form_vari_alloc<Ta, Ra, Ca, Tb, Rb, Cb>* impl_;
 };
-}  // namespace
+}  // namespace internal
 
 template <typename Ta, int Ra, int Ca, typename Tb, int Rb, int Cb>
-inline typename boost::enable_if_c<boost::is_same<Ta, var>::value
-                                       || boost::is_same<Tb, var>::value,
-                                   Eigen::Matrix<var, Cb, Cb> >::type
+inline typename std::enable_if<std::is_same<Ta, var>::value
+                                   || std::is_same<Tb, var>::value,
+                               Eigen::Matrix<var, Cb, Cb> >::type
 quad_form(const Eigen::Matrix<Ta, Ra, Ca>& A,
           const Eigen::Matrix<Tb, Rb, Cb>& B) {
   check_square("quad_form", "A", A);
   check_multiplicable("quad_form", "A", A, "B", B);
 
-  quad_form_vari<Ta, Ra, Ca, Tb, Rb, Cb>* baseVari
-      = new quad_form_vari<Ta, Ra, Ca, Tb, Rb, Cb>(A, B);
+  internal::quad_form_vari<Ta, Ra, Ca, Tb, Rb, Cb>* baseVari
+      = new internal::quad_form_vari<Ta, Ra, Ca, Tb, Rb, Cb>(A, B);
 
   return baseVari->impl_->C_;
 }
 
 template <typename Ta, int Ra, int Ca, typename Tb, int Rb>
-inline typename boost::enable_if_c<
-    boost::is_same<Ta, var>::value || boost::is_same<Tb, var>::value, var>::type
+inline typename std::enable_if<
+    std::is_same<Ta, var>::value || std::is_same<Tb, var>::value, var>::type
 quad_form(const Eigen::Matrix<Ta, Ra, Ca>& A,
           const Eigen::Matrix<Tb, Rb, 1>& B) {
   check_square("quad_form", "A", A);
   check_multiplicable("quad_form", "A", A, "B", B);
 
-  quad_form_vari<Ta, Ra, Ca, Tb, Rb, 1>* baseVari
-      = new quad_form_vari<Ta, Ra, Ca, Tb, Rb, 1>(A, B);
+  internal::quad_form_vari<Ta, Ra, Ca, Tb, Rb, 1>* baseVari
+      = new internal::quad_form_vari<Ta, Ra, Ca, Tb, Rb, 1>(A, B);
 
   return baseVari->impl_->C_(0, 0);
 }
